import React, {useState} from "react";
import {Modal, Space, Button} from "antd";
import {useNavigate} from "react-router-dom";
import {useTranslation} from "react-i18next";
import {useSetState} from "ahooks";

import {showToast} from "@/components/message.ts";
import {push2video} from "@/service/api/article.ts";
import {IconArrowRight} from "@/components/icons";
import ModalWarning from "@/components/icons/ModalWarning.tsx";

export enum ProcessResult {
	All,
	Skip,
	Cancel
}

type PushVideoProps = {
	ids: Id[];
	articles?: ListArticleItem[];
	onResult?: (result: ProcessResult, errorIds: Id[]) => void;
}
export default function ButtonPush2Video(props: PushVideoProps) {
	const [loading, setLoading] = useState(false)
	// const {modal} = App.useApp()
	const [state, setState] = useSetState<{
		modalVisible?: boolean;
		errorTitle?: string[];
		errorIds: Id[]
	}>({
		errorIds: []
	})
	const {t} = useTranslation()
	const navigate = useNavigate()
	/**
	 *
	 * @deprecated 保存即判断，此时暂不提示了
	 */
		// const checkHotNewsValid = async ()=>{
		// 	return new Promise<string>((resolve)=>{
		// 		const manualErrorCount = props.articles?.filter(s=>{
		// 			return s.hot_news.replace(/,/ig,'').trim().length == 0
		// 		})?.length || 0
		// 		if(manualErrorCount == 0) {
		// 			resolve('default')
		// 			return;
		// 		}
		// 		modal.confirm({
		// 			wrapClassName: 'root-modal-confirm',
		// 			icon: <span className="anticon anticon-exclamation-circle"><IconWarningCircle/></span>,
		// 			title: t('modal.push_article.empty_notice_title'),
		// 			content: t('modal.push_article.empty_notice_message'),
		// 			centered:true,
		// 			onOk: () => {
		// 				resolve('auto')
		// 			},
		// 			onCancel: () => {
		// 				resolve('reject')
		// 			}
		// 		})
		// 	})
		// }
	const handlePush = async (action: ProcessResult) => {
			const skip = action === ProcessResult.Skip && state.errorIds.length > 0
			const ids = !skip ? props.ids : props.ids.filter(id => !state.errorIds.includes(id));
			if (skip && (state.errorIds.length == props.ids.length || ids.length == 0)) {
				setState({modalVisible: false})
				return;
			}
			//
			// const result = await checkHotNewsValid();
			// // TODO: 有热点新闻自动?
			// if(result == 'reject'){ // 有热点新闻未填写 但点击取消并终止后续操作
			// 	return;
			// }
			setLoading(true)
			push2video(ids).then(() => {
				setState({modalVisible: false})
				if (skip) {
					props.onResult?.(ProcessResult.Skip, state.errorIds || [])
					return;
				}
				showToast(t('news.push_stream_success'), 'success')
				navigate('/create?state=push-success', {
					state: 'push-success'
				})
				// props.onSuccess?.()
			}).catch(() => {
				showToast(t('service_error'), 'error')
				//showErrorToast
			}).finally(() => {
				setLoading(false)
			})
		}
	// double check 25-02-15 https://pu7y37y121.feishu.cn/docx/FwRrddAFWotRZlxgbr5cP7b6nud
	// 1.normal 数字人播报部分有内容，不少于50字；或者数字人播报部分无内容
	// 2.error 数字人播报部分有内容，但是少于50字
	const checkArticleContent = () => {
		const errors: string[] = [], ids: Id[] = [];

		props.articles?.filter(s => {
			return props.ids.includes(s.id) && (s.metahuman_text && s.metahuman_text.length < 50)
		}).forEach(s => {
			errors.push(s.title)
			ids.push(s.id)
		})
		return {errors, ids}
	}

	const onPushClick = () => {
		if (loading) return;
		if (props.ids.length === 0) {
			showToast(t('news.push_stream_empty'), 'warning')
			return
		}
		// check article content
		const result = checkArticleContent()
		setState({modalVisible: true, errorTitle: result.errors, errorIds: result.ids})
	}
	return (
		<div>
			<button
				className='bg-[#4096ff] hover:bg-blue-600 text-white'
				onClick={onPushClick}
			>
				<span className={'text'}>{loading ? t('news.push_streaming') : t('news.generate_video')}</span>
				<IconArrowRight className={'text-white'}/>
			</button>
			<Modal
				open={state.modalVisible}
				centered
				closeIcon={false}
				footer={null}
				width={440}
			>
				<div className="modal-title flex items-center">
					<div className="anticon anticon-exclamation-circle text-red-400 w-10"><ModalWarning.Icon/></div>
					<div className="text-base">{t('modal.warning')}</div>
				</div>
				<div className="confirm-message-wrapper flex mt-2">
					<div className="min-w-10"></div>
					<div>
						<div className="message text-gray-600" dangerouslySetInnerHTML={{
							__html: t(
								state.errorTitle && state.errorTitle.length > 0
									? (props.ids.length == 1 ? 'modal.push_article.content_error_single' : 'modal.push_article.content_error')
									: (props.ids.length == 1 ? 'modal.push_article.content_normal_single' : 'modal.push_article.content_normal'),
								{count: props.ids.length, error_count: state.errorTitle?.length})
						}}>
						</div>
						{state.errorTitle && state.errorTitle.length > 0 &&
                <div className="error-list text-red-400 mt-6 w-[350px]">
                    <div className="title">{t('modal.push_article.error_title')}:</div>
                    <div className="max-h-[100px] overflow-auto" style={{lineHeight: '20px'}}>
											{state.errorTitle.map((s, idx) => <div key={idx}
											                                       className="error-item overflow-hidden pr-1 text-nowrap overflow-ellipsis">{s}</div>)}
                    </div>
                </div>}
					</div>
				</div>
				<div className="flex justify-end mt-6">
					<Space>
						<Button disabled={loading} onClick={() => {
							setState({modalVisible: false})
						}}>{t('modal.push_article.action_cancel')}</Button>
						{state.errorIds?.length > 0 && (
							<Button
								disabled={loading} type="primary"
								onClick={() => handlePush(ProcessResult.Skip)}
							>{t('modal.push_article.action_skip')}</Button>
						)}
						<Button
							disabled={loading} type={state.errorIds.length == 0 ? 'primary' : 'default'}
							onClick={() => handlePush(ProcessResult.All)}>{t('modal.push_article.action_all')}</Button>
					</Space>
				</div>
			</Modal>
		</div>
	)
}